@@ -1,17 +1,17 @@
 import inspect
 import types
-from flask import Request
 
 
 def dict_has_key_chain(source: dict, key_chain: list[str]) -> bool:
     """
-    Indicate the existence of an element in *source* pointed to by the nested keys chain
-    *[keys[0]: ... :keys[n]*. The path up to he last key in the chain must point to an existing element.
+    Indicate the existence of an element in *source*, pointed to by the nested key chain *[keys[0]: ... :keys[n]*.
+
+    The path up to he last key in the chain must point to an existing element.
     A given key may indicate the element's position within a *list*, using the format *<key>[<pos>]*.
 
-    :param source: The reference dict.
-    :param key_chain: The nested keys chain.
-    :return: Whether the element exists.
+    :param source: the reference dict
+    :param key_chain: the nested key chain
+    :return: whether the element exists
     """
     # initialize the return variable
     result: bool = False
@@ -53,7 +53,8 @@ def dict_has_key_chain(source: dict, key_chain: list[str]) -> bool:
 
 def dict_get_value(source: dict, key_chain: list[str]) -> any:
     """
-    Obtain the value of the element in *source* pointed to by the nested keys chain *[keys[0]: ... :keys[n]*.
+    Obtain the value of the element in *source*, pointed to by the nested key chain *[keys[0]: ... :keys[n]*.
+
     The path up to the last key in the chain must point to an existing element.
     A given key may indicate the element's position within a *list*, using the format *<key>[<pos>]*.
     Return *None* if the sought after value is not found.
@@ -61,211 +62,215 @@ def dict_get_value(source: dict, key_chain: list[str]) -> any:
     since that element might exist therein with the value *None*. To determine whether this is the case,
     use the operation *dict_has_value*.
 
-    :param source: o dict de referência
-    :param key_chain: a cadeia de chaves
-    :return: o valor obtido
+    :param source: the reference dict
+    :param key_chain: the key chain
+    :return: the value obtained
     """
-    # inicializa a variável de retorno
+    # initialize the return variable
     result: any = source
 
-    # percorre as chaves da cadeia
+    # traverse the keys in the chain
     for key in key_chain:
 
-        # é possível prosseguir ?
+        # is it possible to proceed ?
         if not isinstance(result, dict):
-            # não, encerre a operação
+            # no, terminate the operation
             result = None
             break
 
-        # a chave denota um elemento de lista ?
+        # dos the key refer to an elemenent in a list ?
         if key[-1] == "]":
-            # sim, recupere-o
+            # yes, retrieve it
             pos: int = key.find("[")
             inx: int = int(key[pos+1:-1])
             result = result.get(key[:pos])
 
-            # é possível prosseguir ?
+            result = result[inx] if isinstance(result, list) and len(result) > inx else None
+
+            # is it possible to proceed ?
             if isinstance(result, list) and len(result) > inx:
-                # sim, prossiga
+                # yes, proceed
                 result = result[inx]
             else:
-                # não, aborte a operação
+                # no, abort the operation
                 result = None
         else:
-            # não, recupere o elemento 'key' do dicionário
+            # no, retrieve the element corresponding to 'key' in the dictionary
             result = result.get(key)
 
     return result
 
 
-def dict_set_value(target: dict, key_chain: list[str], value: any):
+def dict_set_value(target: dict, key_chain: list[str], value: any) -> None:
     """
-    Atribui ao elemento de *source*, apontado pela cadeia de chaves aninhadas *[keys[0]: ... :keys[n]*,
-    o valor *value*. Caso o elemento final não exista, será criado com o valor especificado.
-    Os elementos intermediários, caso não existam, serão criados com o valor de um *dict* vazio.
+    Assign to an element of *source* the value *value*.
 
-    Uma chave pode indicar a posição do elemento dentro de uma lista, utilizando para tanto
-    o formato *<key>[<pos>]*, e nesse caso, o elemento deve existir.
+    The element in question is pointed to by the key chain *[keys[0]: ... :keys[n]*.
+    If the element does not exist, it is created with the specified value.
+    Any non-existing intermediate elements are created with the value of an empty *dict*.
+    A key might indicate the position of the element within a list, using the format *<key>[<pos>]*.
+    In such a case, that element must exist.
 
-    :param target: o dict de referência
-    :param key_chain: a cadeia de chaves
-    :param value: o valor a ser atribuído ao elemento
+    :param target: the reference dict
+    :param key_chain: the key chain
+    :param value: the value to be assigned
     """
     dict_item: any = target
-    # percorre a cadeia até a penúltima chave
+    # traverse the chain, up to end including its penultimate element
     for key in key_chain[:-1]:
 
-        # é possível prosseguir ?
+        # is it possible to proceed ?
         if not isinstance(dict_item, dict):
-            # não, aborte a operação
+            # no, abort the operation
             break
 
-        # a chave denota um elemento de lista ?
+        # does 'key' refer to a list element ?
         if key[-1] == "]":
-            # sim, recupere-o
+            # yes, retrieve it
             pos: int = key.find("[")
             inx: int = int(key[pos+1:-1])
             dict_item = dict_item.get(key[:pos])
-            # é possível prosseguir ?
+            # is it possible to proceed ?
             if isinstance(dict_item, list) and len(dict_item) > inx:
-                # sim, prossiga
+                # yes, proceed
                 dict_item = dict_item[inx]
             else:
-                # não aborte a operação
+                # no, abort the operation
                 dict_item = None
         else:
-            # não, dict_item tem a chave como elemento ?
+            # no, does 'dict_item' have 'key' as one of its elements ?
             if key not in dict_item:
-                # não, atribua a dict_item a chave com valor de um dicionário vazio
+                # não, assign to 'dict_item' the element 'key' with an empty dict as value
                 dict_item[key] = {}
             dict_item = dict_item.get(key)
 
-    # existe chave e dict_item é um dicionário ?
+    # does a key exist and is 'dict_item'a dict ?
     if len(key_chain) > 0 and isinstance(dict_item, dict):
-        # sim, prossiga
+        # yes, proceed
         key: str = key_chain[-1]
-        # a chave denota um elemento de lista ?
+        # does 'key' refer to a list element ?
         if key[-1] == "]":
-            # sim, recupere-o
+            # yes, retrieve it
             pos: int = key.find("[")
             inx: int = int(key[pos+1:-1])
             dict_item = dict_item.get(key[:pos])
-            # a atribuição é possível ?
+            # is the assignment possible ?
             if isinstance(dict_item, list) and len(dict_item) > inx:
-                # sim, faça-a
+                # yes, do it
                 dict_item[inx] = value
         else:
-            # não, faça a atribuição ao elemento 'key' do dicionário
+            # no, assign 'value' to the element 'key' in the dictionary
             dict_item[key] = value
 
 
 def dict_pop_value(target: dict, key_chain: list[str]) -> any:
     """
-    Remove e retorna o valor do elemento de *source* apontado pela cadeia de chaves aninhadas
-    *[keys[0]: ... :keys[n]*. O caminho até a última chave deve apontar para elementos existentes.
-    Uma chave pode indicar a posição do elemento dentro de uma lista, utilizando para tanto
-    o formato *<key>[<pos>]*. Retorna *None* se o valor procurado não for encontrado.
+    Obtain the value of the element in *source*, pointed to by the nested key chain *[keys[0]: ... :keys[n]*.
 
-    Note que o retorno do valor *None* pode não ser indicativo da ausência do elemento em *source*, quando
-    da invocaçxão dessa operação, uma vez que esse elemento pode ter existido com o próprio valor *None*.
-    Para certificar-se disso, use antes a operação *dict_has_value*.
+    The path up to the last key in the chain must point to an existing element.
+    A given key may indicate the element's position within a *list*, using the format *<key>[<pos>]*.
+    Return *None* if the sought after value is not found.
+    Note that returning *None* might not be indicative of the absence of the element in *source*,
+    since that element might exist therein with the value *None*. To determine whether this is the case,
+    use the operation *dict_has_value*.
 
-    :param target: o dict de referência
-    :param key_chain: a cadeia de chaves
-    :return: o valor removido
+    :param target: the reference dict
+    :param key_chain: the key chain
+    :return: the value removed
     """
-    # inicializa a variável de retorno
+    # initialize the return variable
     result: any = None
 
-    # obtem o elemento pai do elemento denotado pela última chave da cadeia
+    # obtain the element pointed to by the las key in the chain
     parent: dict | None = None
 
-    # a cadeia de chaves contem 1 único elemento ?
+    # does the key chain contain just 1 element ?
     if len(key_chain) == 1:
-        # sim, utilize o dict fornecido
+        # yes, use the provided dict
         parent = target
 
-    # a cadeia de chaves contem mais de 1 elemento ?
+    # does the key chain contain more than 1 element ?
     elif len(key_chain) > 1:
-        # sim, obtenha o elemento pai da última chave da cadeia
+        # yes, retrieve the parent element of the last key in the chain
         parent = dict_get_value(target, key_chain[:-1])
 
-    # o elemento pai é um dicionário ?
+    # is the parent element a dict ?
     if isinstance(parent, dict):
-        # sim, prossiga
+        # yes, proceed
         key: str = key_chain[-1]
 
-        # a última chave da cadeia denota um elemento de lista ?
+        # does the last key un the chain refer to a list element ?
         if key[-1] == "]":
-            # sim, recupere a lista em questão
+            # sim, retrieve the list
             pos: int = key.find("[")
             inx: int = int(key[pos+1:-1])
             key = key[:pos]
             child: any = parent.get(key)
 
-            #  o elemento da última chave da cadeia é uma lista com mais de 'inx' elementos ?
+            # is the element pointed to by the last key in the chain a list with more than 'inx' elements ?
             if isinstance(child, list) and len(child) > inx:
-                # sim, remova o elemento indicado e retorne seu valor
+                # yes, remove that element and return its value
                 result = child.pop(inx)
 
-        # o item pai contem a última chave da cadeia ?
+        # does the parent item contain the last key in the chain ?
         elif key in parent:
-            # sim, remova o elemento indicado e retorne seu valor
+            # yes, remove that element and return its value
             result = parent.pop(key)
 
     return result
 
 
-def dict_replace_value(target: dict, old_value: any, new_value: any):
+def dict_replace_value(target: dict, old_value: any, new_value: any) -> None:
     """
-    Substitui em *target* todas as ocorrências de *old_value* por *new_value*.
+    Replace in *target* all occurrences of *old_value* with *new_value*.
 
-    :param target: o dict de referência
-    :param old_value: o valor a ser substituído
-    :param new_value: o novo valor
+    :param target: the reference dict
+    :param old_value: the value to be replaced
+    :param new_value: the new value
     """
-    def list_replace_value(items: list[any], old_val: any, new_val: any):
-        # percorre a lista
+    def list_replace_value(items: list[any], old_val: any, new_val: any) -> None:
+        # traverse the list
         for item in items:
 
-            # o item é um dicionário ?
+            # is 'item' a dict ?
             if isinstance(item, dict):
-                # sim, processe-o recursivamente
+                # yes, process it recursively
                 dict_replace_value(item, old_val, new_val)
 
-            # o item é uma lista ?
+            # is 'item' a list ?
             elif isinstance(item, list):
-                # sim, processe-o recursivamente
+                # yes, process it recursively
                 list_replace_value(item, old_val, new_val)
 
-    # percorre o dicionário
+    # traverse the dict
     for curr_key, curr_value in target.items():
 
-        # o valor atual é o valor buscado ?
+        # is 'curr_value' the value to be replaced ?
         if curr_value == old_value:
-            # sim, substitua-o
+            # yes, replace it
             target[curr_key] = new_value
 
-        # o valor atual é um dicionário ?
+        # is 'curr_value' a dict ?
         elif isinstance(curr_value, dict):
-            # sim, processe-o recursivamente
+            # yes, process it recursively
             dict_replace_value(curr_value, old_value, new_value)
 
-        # o valor atual é uma lista ?
+        # is 'curr_value' a list ?
         elif isinstance(curr_value, list):
-            # sim, processe-o recursivamente
+            # yes, process it recursively
             list_replace_value(curr_value, old_value, new_value)
 
 
 def dict_get_key(source: dict, value: any) -> any:
     """
-    Retorna a chave em *source*, associada à primeira ocorrência de *value* encontrada,
-    ou *None*, se nenhuma chave for encontrada. Apenas os atributos no primeiro nível
-    em *source* são inspecionados.
+    Return the key in *source*, mapping the first occurrence of *value* found.
 
-    :param source: dicionário a ser pesquisado
-    :param value: valor de referência
-    :return: primeira chave associada ao valor de referência
+    Return *None*, if no key is found.
+    No recursion is attempted; only the first-level attributes in *source* are inspected.
+
+    :param source: dict to search
+    :param value: the reference value
+    :return: first key mapping the reference value
     """
     result: any = None
     for key, val in source.items():
@@ -278,26 +283,28 @@ def dict_get_key(source: dict, value: any) -> any:
 
 def dict_get_keys(source: dict, value: any) -> list[str]:
     """
-    Restorna lista com todas as chaves ne primeiro nível em *source*, associadas a *value*,
-    ou *[]* se nenhuma chave for encontrada.
+    Return all keys in *source*, mapping the value *value*.
 
-    :param source: dicionário a ser pesquisado
-    :param value: valor de referência
-    :return: lista de chaves associadas ao valor de referência
+    Return *[]* if no key is found.
+
+    :param source: dict to search
+    :param value: the reference value
+    :return: list containing all keys mapping the reference value
     """
     return [key for key, val in source.items() if val == value]
 
 
-def dict_merge(target: dict, source: dict):
+def dict_merge(target: dict, source: dict) -> None:
     """
-    Percorre os elementos de *source* para atualizar *target*, obedecendo aos seguintes os critérios:
+    Percorre os elementos de *source* para atualizar *target*, obedecendo um conjunto de critérios.
 
-    - acrescentar o elemento a *target*, se não existir
-    - se o elemento existir em *target*:
+    Os critérios a sere mseguidos são:
+      - acrescentar o elemento a *target*, se não existir
+      - se o elemento existir em *target*:
 
-      -   processar recursivamente os dois elementos, se ambos forem do tipo *dict*
-      -   acrescentar os itens faltantes, se ambos forem do tipo *list*
-      -   substituir o elemento em *target* se for de outro tipo, ou se os tipos forem diferentes entre si
+        - processar recursivamente os dois elementos, se ambos forem do tipo *dict*
+        - acrescentar os itens faltantes, se ambos forem do tipo *list*
+        - substituir o elemento em *target* se for de outro tipo, ou se os tipos forem diferentes entre si
 
     :param target: o dicionário a ser atualizado
     :param source: o dicionário com os novos elementos
@@ -329,10 +336,11 @@ def dict_merge(target: dict, source: dict):
             target[skey] = svalue
 
 
-def dict_coalesce(target: dict, key_chain: list[str]):
+def dict_coalesce(target: dict, key_chain: list[str]) -> None:
     """
-    Coalesce o elemento do tipo *list* em *target* no nível *n*, apontado pela cadeia de
-    chaves aninhadas *[keys[0]: ... :keys[n]*, com a lista no nível imediatamente anterior,
+    Coalesce o elemento do tipo *list* em *target* no nível *n*, com a lista no nível imediatamente anterior.
+
+    Esse elemento é apontado pela cadeia de chaves aninhadas *[keys[0]: ... :keys[n]*, e é processado
     como uma sequência de multiplos elementos. Para tanto, as duas últimas chaves da cadeia
     *key_chain* devem estar associadas a valores do tipo *list*.
 
@@ -364,9 +372,9 @@ def dict_coalesce(target: dict, key_chain: list[str]):
                 # termina a operação
                 curr_dict = None
                 break
-            else:
-                # não, prossiga com o valor associado a key
-                curr_dict = curr_dict.get(key)
+
+            # prossiga com o valor associado a key
+            curr_dict = curr_dict.get(key)
 
         # curr_dict é um dicionário contendo a penúltima chave ?
         if isinstance(curr_dict, dict) and \
@@ -425,11 +433,12 @@ def dict_coalesce(target: dict, key_chain: list[str]):
             curr_dict[key_chain[-2]] = penultimate_list
 
 
-def dict_reduce(target: dict, key_chain: list[str]):
+def dict_reduce(target: dict, key_chain: list[str]) -> None:
     """
-    Realoca os elementos de *target* no nível *n*, apontados pela cadeia de chaves aninhadas
-    *[keys[0]: ... :keys[n]*, para o nível imediatamente acima, e remove o elemento no nivel *n*
-    ao final.
+    Realoca os elementos de *target* no nível *n*, para o nível imediatamente acima.
+
+    Esses elementos são apontados pela cadeia de chaves aninhadas *[keys[0]: ... :keys[n]*.
+    O elemento no nivel *n* é removido, ao final.
 
     :param target: o dicionário a ser reduzido
     :param key_chain: a cadeia de chaves
@@ -459,9 +468,9 @@ def dict_reduce(target: dict, key_chain: list[str]):
                 # termine a operação
                 curr_dict = None
                 break
-            else:
-                # não, prossiga com o valor associado a key
-                curr_dict = curr_dict.get(key)
+
+            # prossiga com o valor associado a key
+            curr_dict = curr_dict.get(key)
 
         last_key: str = key_chain[-1]
         # curr_dict contem um dicionário associado a last_key ?
@@ -475,8 +484,9 @@ def dict_reduce(target: dict, key_chain: list[str]):
 
 def dict_from_list(source: list[dict], key_chain: list[str], value: any) -> dict:
     """
-    Localiza em *source*, e retorna, o elemento do tipo *dict* contendo a cadeia de chaves
-    *key_chain* com o valor *value*. Retorna *None* se esse *dict* não for encontrado.
+    Localiza em *source*, e retorna, o elemento do tipo *dict* com o valor *value* na cadeia de chaves *key_chain*.
+
+    Retorna *None* se esse *dict* não for encontrado.
 
     :param source: a lista a ser inspecionada
     :param key_chain: a cadeia de chaves usada na busca
@@ -497,8 +507,9 @@ def dict_from_list(source: list[dict], key_chain: list[str], value: any) -> dict
 
 def dict_from_object(source: object) -> dict:
     """
-    Percorre *source* e cria um *dict* com seus atributos contendo valores não nulos. *source* pode ser
-    qualquer objeto, especialmente aqueles que tenham sido decorados com *@dataclass*.
+    Percorre *source* e cria um *dict* com seus atributos contendo valores não nulos.
+
+    *source* pode ser qualquer objeto, especialmente aqueles que tenham sido decorados com *@dataclass*.
 
     :param source: o objeto de referência
     :return: dicionário com estrutura equivalente ao objeto de referência
@@ -538,28 +549,12 @@ def dict_from_object(source: object) -> dict:
     return result
 
 
-def dict_from_form(request: Request) -> dict:
-    """
-    Constrói e retorna um *dict* com os parâmetros encontrados no form existente em *request*.
-
-    :param request: the HTTP request
-    :return: dicionários contendo os parâmetros encontrados.
-    """
-
-    # inicializa variável de retorno
-    result: dict = {}
-
-    # percorre os parâmetros do form
-    for key, value in request.form.items():
-        result[key] = value
-
-    return result
-
-
 def dict_transform(source: dict, from_to_keys: list[tuple[str, str]],
                    prefix_from: str = None, prefix_to: str = None) -> dict:
     """
-    Constrói um novo *dict*, atribuindo a cada elemento indicado pelo segundo elemento de uma
+    Constrói um novo *dict*, segundo as regras seguintes.
+
+    Esse dicionário é construído atribuindo-se a cada elemento indicado pelo segundo elemento de uma
     tupla contendo uma cadeia de chaves aninhadas em *from_to_keys*, o valor do elemento
     de *source* indicado pelo primeiro elemento da tupla, também contendo uma cadeia de chaves
     aninhadas, respectivamente para todos os elementos mapeados em *from_to_keys*.
@@ -584,7 +579,7 @@ def dict_transform(source: dict, from_to_keys: list[tuple[str, str]],
     for key, value in source.items():
 
         # define a cadeia de chaves de origem
-        if prefix_from is None:
+        if prefix_from:
             from_keys: str = key
         else:
             from_keys: str = f"{prefix_from}.{key}"
@@ -593,7 +588,7 @@ def dict_transform(source: dict, from_to_keys: list[tuple[str, str]],
         to_keys: str = list_find_coupled(from_to_keys, from_keys)
 
         # o destino foi definido ?
-        if to_keys is not None:
+        if to_keys:
             # sim, obtenha o valor de destino
             if isinstance(value, dict):
                 # valor é um dicionário, transforme-o
@@ -606,7 +601,7 @@ def dict_transform(source: dict, from_to_keys: list[tuple[str, str]],
                 to_value: any = value
 
             # o prefixo de destino foi definido e ocorre na cadeia de destino ?
-            if prefix_to is not None and to_keys.startswith(prefix_to):
+            if prefix_to and to_keys.startswith(prefix_to):
                 # sim, remova o prefixo
                 to_keys = to_keys[len(prefix_to)+1:]
             to_keys_deep: list[str] = list_unflatten(to_keys)
@@ -617,17 +612,18 @@ def dict_transform(source: dict, from_to_keys: list[tuple[str, str]],
     return result
 
 
-def dict_listify(target: dict, key_chain: list[str]):
+def dict_listify(target: dict, key_chain: list[str]) -> None:
     """
-    Insere o valor do item de *target* apontado pela cadeia de chaves aninhadas
-    *[keys[0]: ... :keys[n]* em uma lista, se esse valor já não for uma lista.
+    Insere o valor do item de *target* apontado pela cadeia de chaves *[keys[0]: ... :keys[n]* em uma lista.
+
+    Essa inserção ocorrerá apenas se esse valor já não for uma lista.
     Todas as listas eventualmente encontradas no percurso até a penúltima chava
     da cadeia serão recursivamente processadas.
 
     :param target: dicionário a ser modificado
     :param key_chain: cadeia de chaves aninhadas apontando para o item em questão
     """
-    def items_listify(in_targets: list, in_keys: list[str]):
+    def items_listify(in_targets: list, in_keys: list[str]) -> None:
 
         # percorra os itens da lista
         for in_target in in_targets:
@@ -688,18 +684,18 @@ if __name__ == "__main__":
     ]
     s2 = dict_transform(s1, mapping)
 
-    print(f"dict original:     {s1}")
+    print(f"original dict:  {s1}")
     keys: list[str] = ["a1", "b1"]
-    print(f"cadeia de redução: {keys}")
+    print(f"reduced chain:  {keys}")
     dict_reduce(s1, keys)
-    print(f"dict reduzido:     {s1}")
+    print(f"reduced dict:   {s1}")
     keys = ["a1", "c1", "d"]
-    print(f"cadeia para list.: {keys}")
+    print(f"listified chain: {keys}")
     dict_listify(s1, keys)
-    print(f"dict listificado:  {s1}")
+    print(f"listified dict:  {s1}")
     keys = ["a1", "c1", "d"]
-    print(f"cadeia para coal.: {keys}")
+    print(f"coalesced chain: {keys}")
     dict_coalesce(s1, keys)
-    print(f"dict coalescido:   {s1}")
-    print(f"mapeamento:        {mapping}")
-    print(f"dict transformado: {s2}")
+    print(f"coalesced dict:   {s1}")
+    print(f"mapping:          {mapping}")
+    print(f"transformed dict: {s2}")
