@@ -104,7 +104,7 @@ def http_json_from_request(request: Request) -> dict:
         resp: str = request.get_data(as_text=True)
         # does the request contain input data ?
         if len(resp) > 0:
-            # yes, possibly mal-fomed JSON
+            # yes, possibly mal-formed JSON
             raise
 
     return result
@@ -131,7 +131,7 @@ def http_json_from_get(errors: list[str] | None, url: str, headers: dict = None,
     result: dict | None = None
 
     if logger:
-        logger.debug(f"Invoking GET: '{url}'")
+        logger.debug(f"Invoking '{url}'")
 
     try:
         response: requests.Response = requests.get(url=url,
@@ -140,7 +140,8 @@ def http_json_from_get(errors: list[str] | None, url: str, headers: dict = None,
                                                    timeout=timeout)
         result = response.json()
         if logger:
-            logger.debug(f"Invoked '{url}', status '{http_status_name(response.status_code)}'")
+            logger.debug(f"Invoked '{url}', "
+                         f"status {response.status_code} ({http_status_name(response.status_code)})")
     except Exception as e:
         err_msg: str = f"Error invoking '{url}': '{exc_format(e, sys.exc_info())}'"
         if logger:
@@ -174,7 +175,7 @@ def http_json_from_post(errors: list[str] | None, url: str, headers: dict = None
     result: dict | None = None
 
     if logger:
-        logger.debug(f"Invoking POST: '{url}'")
+        logger.debug(f"Invoking '{url}'")
 
     try:
         response: requests.Response = requests.post(url=url,
@@ -185,7 +186,8 @@ def http_json_from_post(errors: list[str] | None, url: str, headers: dict = None
                                                     timeout=timeout)
         result = response.json()
         if logger:
-            logger.debug(f"Invoked '{url}', status '{http_status_name(response.status_code)}'")
+            logger.debug(f"Invoked '{url}', "
+                         f"status {response.status_code} ({http_status_name(response.status_code)})")
     except Exception as e:
         err_msg: str = f"Error invoking '{url}': '{exc_format(e, sys.exc_info())}'"
         if logger:
